aboutsummaryrefslogtreecommitdiff
path: root/platform/fpga/openpiton/platform.c
diff options
context:
space:
mode:
Diffstat (limited to 'platform/fpga/openpiton/platform.c')
-rw-r--r--platform/fpga/openpiton/platform.c19
1 files changed, 4 insertions, 15 deletions
diff --git a/platform/fpga/openpiton/platform.c b/platform/fpga/openpiton/platform.c
index 4c83f6d..019dcc5 100644
--- a/platform/fpga/openpiton/platform.c
+++ b/platform/fpga/openpiton/platform.c
@@ -182,22 +182,12 @@ static int openpiton_timer_init(bool cold_boot)
}
/*
* Reboot the openpiton.
*/
-static int openpiton_system_reboot(u32 type)
+static int openpiton_system_reset(u32 type)
{
/* For now nothing to do. */
- sbi_printf("System reboot\n");
- return 0;
-}
-
-/*
- * Shutdown or poweroff the openpiton.
- */
-static int openpiton_system_shutdown(u32 type)
-{
- /* For now nothing to do. */
- sbi_printf("System shutdown\n");
+ sbi_printf("System reset\n");
return 0;
}
@@ -218,8 +208,7 @@ const struct sbi_platform_operations platform_ops = {
.timer_value = clint_timer_value,
.timer_event_start = clint_timer_event_start,
.timer_event_stop = clint_timer_event_stop,
- .system_reboot = openpiton_system_reboot,
- .system_shutdown = openpiton_system_shutdown
+ .system_reset = openpiton_system_reset
};
const struct sbi_platform platform = {
@@ -182,22 +182,12 @@ static int openpiton_timer_init(bool cold_boot)
}
/*
- * Reboot the openpiton.
+ * Reset the openpiton.
*/